@@ -1,6 +1,6 @@
 /* Gnome Music Player Client (GMPC)
- * Copyright (C) 2004-2010 Qball Cow <qball@sarine.nl>
- * Project homepage: http://gmpc.wikia.com/
+ * Copyright (C) 2004-2011 Qball Cow <qball@gmpclient.org>
+ * Project homepage: http://gmpclient.org/
  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #ifndef __MPDINTERACTION_H__
 #define __MPDINTERACTION_H__
 int play_song(void);
+int pause_song(void);
 int stop_song(void);
 int next_song(void);
 int prev_song(void);
@@ -33,6 +34,7 @@ void consume_toggle(void);
 int  seek_ns(int n);
 int  seek_ps(int n);
 int connect_to_mpd(void);
+void disconnect_from_mpd();
 void song_fastforward(void);
 void song_fastbackward(void);
 void volume_up(void);
